#
# spec file for package googler
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           googler
Version:        4.3.13
Release:        1.4
Summary:        Google Search, Google Site Search, Google News from the terminal
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Utilities
URL:            https://github.com/oksiquatzel/googler
Source:         https://github.com/oksiquatzel/googler/archive/v%{version}.tar.gz
BuildRequires:  python3-devel >= 3.7
BuildArch:      noarch

%description
googler is a power tool to Google (Web & News) and Google Site Search
from the command-line. It shows the title, URL and abstract for each
result, which can be directly opened in a browser from the terminal.
Results are fetched in pages (with page navigation). Supports
sequential searches in a single googler instance.

%prep
%autosetup

%build
%make_build disable-self-upgrade

%install
make PREFIX=%{buildroot}%{_prefix} install
# Fix the googler.noarch: E: env-script-interpreter (Badness: 9) error by
# rpmlint.
sed -i 's|%{_bindir}/env\ python|%{_bindir}/python|1' %{buildroot}/%{_bindir}/%{name}

# wrong location
rm -rf %{buildroot}%{_datadir}/doc/googler

install -Dm644 auto-completion/fish/googler.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/googler.fish
install -Dm644 auto-completion/bash/googler-completion.bash %{buildroot}%{_datadir}/bash-completion/completions/googler
install -Dm644 auto-completion/zsh/_googler %{buildroot}%{_datadir}/zsh/site-functions/_googler

%files
%license LICENSE
%doc CHANGELOG README.md
%{_bindir}/googler
%{_mandir}/man1/googler.*
%{_datadir}/bash-completion/completions/
%dir %{_datadir}/fish/
%{_datadir}/fish/vendor_completions.d/
%{_datadir}/zsh/

%changelog
* Tue Apr 25 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 4.3.13
  * removed python version 3.6 from build
  * Fix google Video search
  * Fix parsing of Results
  * Fix html class of result nodes (#393, fixes #392)
  * Do not sabotage stdin of url_handler (#386)
- changed upstream repository
* Fri Jun 24 2022 openqa container_bot <ggkioulis@suse.com>
- Update to the latest version and solve bsc1200312
* Fri Jun 24 2022 openqa container_bot <ggkioulis@suse.com>
- Update to the latest version and solve bsc1200312
* Fri Jun 24 2022 openqa container_bot <ggkioulis@suse.com>
- Update to the latest version and solve bsc1200312
* Thu Jun 16 2022 openqa container_bot <ggkioulis@suse.com>
- Update to the latest version and solve bsc1200312
* Sun Oct 11 2020 Dilawar Singh <dilawar.s.rajput@gmail.com>
- Update to version 4.3.1
  * several important parser fixes
  * retire Python v3.5, add v3.9
- Update to version 4.3
  * fix recent break due to server-side changes
  * option `-e`/`--exclude` to exclude site from results
  * option `-g`/`--geoloc` to specify geolocation
  * replace uuid1 with uuid4 in request
- Update to version 4.2
  * support GUI platform browsers on WSL
  * support Wayland native copier `wl-copy`
  * program options `--ipv4`, `--ipv6`; ipv4 preferred by default
  * deduplicate results
  * fix sitelinks parsing
  * combine consecutive whitespaces
  * fix extraction of matched keywords
  * fix match highlighting
  * no additional blank line for empty abstracts
  * undocumented debug option `--parse` to parse dumped HTML
* Fri May  1 2020 Dilawar Singh <dilawar.s.rajput@gmail.com>
- Update to version 4.1
  * search Google Videos
  * options --from and --to to specify date range for search
  * update parser to handle new layout for Google News results
  * strip trailing comma from metadata
  * add auto-generated packages for new distros, remove obsolete
* Wed Nov 27 2019 Dilawar Singh <dilawar.s.rajput@gmail.com>
- Update to version 4.0
  * Switch to modern UA and fix parser to handle new result format
  - fixes #306 Googler no results on v3.9 (due to google's recent layout changes)
  * Text-wrapping
* Thu May 30 2019 Dilawar Singh <dilawar.s.rajput@gmail.com>
- Update to version 3.9
  * fix issue - googler showing "No results."
  * show matched keywords in bold in result abstracts
  * option --colorize for more control on colors
  * better support for colors on Windows
  * switch to CircleCI from Travis
  * option --noua is deprecated (noop) and will be removed in future
* Thu Mar 28 2019 dilawar.s.rajput@gmail.com
- Update to version 3.8
  * A complete parser rewrite
  * Visual redesign of the output format
  * Text-wrapping for CJK wide characters
  * Refresh current page on URL expansion toggle
  * Available on Raspbian testing and Chocolatey
  * Several important fixes
* Sat Mar 16 2019 dilawar.s.rajput@gmail.com
- Update to version 3.7.1
  * Custom user agent
  * Fix to unescape auto-completions
- Update to version 3.7
  * Support xclip as a clipboard utility on *nix
  * Support GNU Screen and tmux as clipboard fallback
  * Support Termux clipboard on Android
- Update to version 3.6
  * Decode auto-completion info as per charset in response header
  * Ignore trailing / in proxy
  * Some heath sites added to googler @t
  * User agent updated to Firefox 60
  * Availability on Fedora and openSUSE
  * More auto-generated packages
* Fri Mar 30 2018 dilawar.s.rajput@gmail.com
- Update to version 3.5
  * URL folding to show only domain name
  * Omniprompt key c to copy URL to clipboard
  * Support env var DISABLE_PROMPT_COLOR to disable prompt color (see #203)
- Changes from version 3.4
  * Support custom URL handler script or cli utility (option --url-handler)
  * Support text browser override with GUI browser (omniprompt key O)
  * A stunning project logo! (designed by zmwangx - github user id)
* Sun Aug 20 2017 mailaender@opensuse.org
- Update to version 3.3
  * Search auto-completion (using completion scripts)
  * Python 3.6 support
  * Automated release package builds using PackageCore
- Changes from version 3.2
  * Basic authentication with --proxy
  * Option --unfilter to include similar results
  * New googler @ts : Manga Reader, Mac Rumors, OMG! Ubuntu!
  * Fix: skip certain card results with --noua
  * Options --json and --exact decoupled
- Changes from version 3.1
  * Search result metadata (e.g. IMDB rating)
  * Multi-site search
  * Browse numeric ranges at omniprompt
  * googler@ - Financial Times, The Pirate Bay added
- Changes from version 3.0
  * Introducing googler @t add-on!
  * Open multiple indices from omniprompt
  * Open all indices from omniprompt
  * Option --enable-browser-output is now --show-browser-logs
  * Multiple bug fixes
* Mon Dec 26 2016 mailaender@opensuse.org
- initial packaging of version 2.9
